@@ -9,6 +9,7 @@ from .value_obj import (
     EnvVarSourceType,
     HTTPHeader,
     ImagePullPolicy,
+    Integer,
     JobStatus,
     LabelDict,
     LabelSelectorOperator,
@@ -910,4 +911,17 @@ class Job(ExpiredEntity):
         self.status=status
         self.parallelism=parallelism
         self._life_time=_life_time
-        super().__init__(_life_time)
\ No newline at end of file
+        super().__init__(_life_time)
+
+class PodLogSetting(Entity):
+    def __init__(
+        self,
+        namespace_name: Name,
+        pod_name: Name,
+        container_name: Optional[Name] = None,
+        tail_lines: Integer = Integer(500)
+    ):
+        self.namespace_name=namespace_name
+        self.pod_name=pod_name
+        self.container_name=container_name
+        self.tail_lines=tail_lines
\ No newline at end of file
