@@ -3,9 +3,11 @@ from ddd_objects.domain.repository import Repository
 from .entity import(
     Condition,
     Job,
-    JobSetting
+    JobSetting,
+    PodLogSetting
 )
 from .value_obj import(
+    Integer,
     Name
 )
 from ..domain.entity import (
@@ -95,7 +97,7 @@ class K3SRepository(Repository):
     def get_ingresses(self, cluster_name: Name, namespace_name: Name)->Optional[List[Ingress]]:
         raise NotImplementedError
 
-    def get_pod_log(self, cluster_name: Name, namespace_name: Name, pod_name: Name, tail_lines: Number = 500)->Optional[str]:
+    def get_pod_log(self, cluster_name: Name, pod_log_setting: PodLogSetting)->Optional[str]:
         raise NotImplementedError
 
     def create_job(self, cluster_name: Name, job_setting: JobSetting)->Optional[Job]:
